@@ -1,6 +1,7 @@
 ## internal method for parsing a list of package dependencies into pkg URLs
 
-format_depend <- function(package, version, remote_provider) {
+format_depend <- function(package, version, remote_provider,
+                          verbose = FALSE) {
 
   dep <- list(
     "@type" = "SoftwareApplication",
@@ -15,7 +16,7 @@ format_depend <- function(package, version, remote_provider) {
     dep$version <- version
   }
 
-  dep$provider <- guess_provider(package)
+  dep$provider <- guess_provider(package, verbose)
 
   ## implemention could be better, e.g. support versioning
   #  dep$`@id` <- guess_dep_id(dep)
@@ -42,7 +43,7 @@ get_sameAs <- function(provider, remote_provider, identifier) {
   # The remote provider takes precedence over the non-remote provider
   if (remote_provider != "") {
 
-    get_url_github(stringr::str_remove(remote_provider, "github::"))
+    get_url_github(gsub("github::", "", remote_provider))
 
   } else if (! is.null(provider) && provider$name %in% names(url_generators)) {
 
@@ -52,11 +53,12 @@ get_sameAs <- function(provider, remote_provider, identifier) {
 }
 
 
-parse_depends <- function(deps) {
+parse_depends <- function(deps, verbose = FALSE) {
 
   purrr::pmap(
     list(deps$package, deps$version, deps$remote_provider),
-    format_depend
+    format_depend,
+    verbose = verbose
   )
 }
 
@@ -104,15 +106,25 @@ add_remote_to_dep <- function(package, remotes) {
 
 
 # helper to get system dependencies
-get_sys_links <- function(pkg, description = "") {
+get_sys_links <- function(pkg, description = "", verbose = FALSE) {
+  if (verbose) {
+    cli::cat_bullet("Getting sysreqs URL from sysreqs API", bullet = "continue")
+  }
 
-  get_url_rhub("get", unique(c(
+  data <- get_url_rhub("get", unique(c(
     get_rhub_json_names("pkg", pkg),
-    get_rhub_json_names("map", curl::curl_escape(description))
+    get_rhub_json_names("map", utils::URLencode(description, reserved = TRUE))
   )))
+
+  if (verbose) {
+    cli::cat_bullet("Got sysreqs URL from sysreqs API!", bullet = "tick")
+  }
+
+  data
 }
 
 get_rhub_json_names <- function(a, b) {
+
   sapply(
     X = jsonlite::fromJSON(get_url_rhub(a, b), simplifyVector = FALSE),
     FUN = names
@@ -125,10 +137,10 @@ format_sys_req <- function(url) {
 }
 
 #' @importFrom pingr is_online
-parse_sys_reqs <- function(pkg, sys_reqs) {
+parse_sys_reqs <- function(pkg, sys_reqs, verbose = FALSE) {
 
   if(!pingr::is_online()) return(NULL)
 
-  urls <- get_sys_links(pkg, description = sys_reqs)
+  urls <- get_sys_links(pkg, description = sys_reqs, verbose)
   purrr::map(urls, format_sys_req)
 }
